summaryrefslogtreecommitdiff
path: root/svx
diff options
context:
space:
mode:
authorMichael T. Whiteley <mike@whiteley.org>2011-12-07 02:33:51 -0800
committerTor Lillqvist <tlillqvist@suse.com>2011-12-08 11:32:41 +0200
commitdcfd4beb213c551f6ef6ba379651bf303bd9017a (patch)
treea819f50716357c2a5561f6b9a09809cfc52d7dbf /svx
parentad2eb6c4ba3ca36e2302c721a106dac80d266325 (diff)
childs -> children
Diffstat (limited to 'svx')
-rwxr-xr-xsvx/inc/accessibility.hrc2
-rw-r--r--svx/inc/svx/checklbx.hxx2
-rw-r--r--svx/inc/svx/dlgctrl.hxx2
-rw-r--r--svx/source/accessibility/svxrectctaccessiblecontext.cxx40
-rw-r--r--svx/source/dialog/checklbx.cxx4
-rw-r--r--svx/source/dialog/dlgctrl.cxx2
-rw-r--r--svx/source/form/fmexpl.cxx16
-rw-r--r--svx/source/form/fmshimp.cxx2
-rw-r--r--svx/source/form/fmvwimp.cxx6
-rw-r--r--svx/source/form/formcontroller.cxx20
-rw-r--r--svx/source/form/navigatortree.cxx8
-rw-r--r--svx/source/form/navigatortreemodel.cxx6
-rw-r--r--svx/source/inc/fmexpl.hxx6
-rw-r--r--svx/source/inc/formcontroller.hxx2
-rw-r--r--svx/source/inc/svxrectctaccessiblecontext.hxx4
-rw-r--r--svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx4
16 files changed, 63 insertions, 63 deletions
diff --git a/svx/inc/accessibility.hrc b/svx/inc/accessibility.hrc
index 3e386be0daf1..32268389ce5f 100755
--- a/svx/inc/accessibility.hrc
+++ b/svx/inc/accessibility.hrc
@@ -43,7 +43,7 @@
#define RID_SVXSTR_A11Y_AND (RID_SVXSTR_ACCESSIBILITY_START + 11)
-// SvxRectCtl & childs
+// SvxRectCtl & children
#define RID_SVXSTR_RECTCTL_ACC_START (RID_SVXSTR_ACCESSIBILITY_START + 20)
#define RID_SVXSTR_RECTCTL_ACC_CORN_NAME (RID_SVXSTR_RECTCTL_ACC_START + 0)
#define RID_SVXSTR_RECTCTL_ACC_CORN_DESCR (RID_SVXSTR_RECTCTL_ACC_START + 1)
diff --git a/svx/inc/svx/checklbx.hxx b/svx/inc/svx/checklbx.hxx
index 8b44b74096ce..fbedbd5a6f75 100644
--- a/svx/inc/svx/checklbx.hxx
+++ b/svx/inc/svx/checklbx.hxx
@@ -53,7 +53,7 @@ private:
using SvTreeListBox::InsertEntry;
// Avoid ambiguity with new InsertEntry:
virtual SvLBoxEntry* InsertEntry( const XubString& rText, SvLBoxEntry* pParent,
- sal_Bool bChildsOnDemand,
+ sal_Bool bChildrenOnDemand,
sal_uIntPtr nPos, void* pUserData,
SvLBoxButtonKind eButtonKind );
diff --git a/svx/inc/svx/dlgctrl.hxx b/svx/inc/svx/dlgctrl.hxx
index 02fa0d2215de..1e1f11a9c7ec 100644
--- a/svx/inc/svx/dlgctrl.hxx
+++ b/svx/inc/svx/dlgctrl.hxx
@@ -121,7 +121,7 @@ public:
void SetState( CTL_STATE nState );
- sal_uInt8 GetNumOfChilds( void ) const; // returns number of usable radio buttons
+ sal_uInt8 GetNumOfChildren( void ) const; // returns number of usable radio buttons
Rectangle CalculateFocusRectangle( void ) const;
Rectangle CalculateFocusRectangle( RECT_POINT eRectPoint ) const;
diff --git a/svx/source/dialog/checklbx.cxx b/svx/source/dialog/checklbx.cxx
index 4a9ad6d6137a..2e5eb1ebd1f9 100644
--- a/svx/source/dialog/checklbx.cxx
+++ b/svx/source/dialog/checklbx.cxx
@@ -267,9 +267,9 @@ void SvxCheckListBox::KeyInput( const KeyEvent& rKEvt )
// -----------------------------------------------------------------------
-SvLBoxEntry* SvxCheckListBox::InsertEntry( const XubString& rText, SvLBoxEntry* pParent, sal_Bool bChildsOnDemand, sal_uIntPtr nPos, void* pUserData, SvLBoxButtonKind eButtonKind )
+SvLBoxEntry* SvxCheckListBox::InsertEntry( const XubString& rText, SvLBoxEntry* pParent, sal_Bool bChildrenOnDemand, sal_uIntPtr nPos, void* pUserData, SvLBoxButtonKind eButtonKind )
{
- return SvTreeListBox::InsertEntry( rText, pParent, bChildsOnDemand, nPos, pUserData, eButtonKind );
+ return SvTreeListBox::InsertEntry( rText, pParent, bChildrenOnDemand, nPos, pUserData, eButtonKind );
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/svx/source/dialog/dlgctrl.cxx b/svx/source/dialog/dlgctrl.cxx
index 18cc826bb3df..4187f369b143 100644
--- a/svx/source/dialog/dlgctrl.cxx
+++ b/svx/source/dialog/dlgctrl.cxx
@@ -659,7 +659,7 @@ void SvxRectCtl::SetState( CTL_STATE nState )
( (SvxTabPage*) GetParent() )->PointChanged( this, eRP );
}
-sal_uInt8 SvxRectCtl::GetNumOfChilds( void ) const
+sal_uInt8 SvxRectCtl::GetNumOfChildren( void ) const
{
return ( eCS == CS_ANGLE )? 8 : 9;
}
diff --git a/svx/source/form/fmexpl.cxx b/svx/source/form/fmexpl.cxx
index b67f2a1250d6..95ae0a8e04a7 100644
--- a/svx/source/form/fmexpl.cxx
+++ b/svx/source/form/fmexpl.cxx
@@ -311,9 +311,9 @@ void FmEntryData::Clear()
}
//------------------------------------------------------------------------
-sal_Bool FmEntryData::IsEqualWithoutChilds( FmEntryData* pEntryData )
+sal_Bool FmEntryData::IsEqualWithoutChildren( FmEntryData* pEntryData )
{
- RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmEntryData::IsEqualWithoutChilds" );
+ RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmEntryData::IsEqualWithoutChildren" );
if(this == pEntryData)
return sal_True;
@@ -332,7 +332,7 @@ sal_Bool FmEntryData::IsEqualWithoutChilds( FmEntryData* pEntryData )
if( !pEntryData->GetParent() && !pParent )
return sal_True;
- if( !pParent->IsEqualWithoutChilds(pEntryData->GetParent()) )
+ if( !pParent->IsEqualWithoutChildren(pEntryData->GetParent()) )
return sal_False;
return sal_True;
@@ -395,7 +395,7 @@ FmEntryData* FmFormData::Clone()
}
//------------------------------------------------------------------------
-sal_Bool FmFormData::IsEqualWithoutChilds( FmEntryData* pEntryData )
+sal_Bool FmFormData::IsEqualWithoutChildren( FmEntryData* pEntryData )
{
if(this == pEntryData)
return sal_True;
@@ -405,7 +405,7 @@ sal_Bool FmFormData::IsEqualWithoutChilds( FmEntryData* pEntryData )
if( (XForm*)m_xForm.get() != (XForm*)pFormData->GetFormIface().get() )
return sal_False;
- return FmEntryData::IsEqualWithoutChilds( pFormData );
+ return FmEntryData::IsEqualWithoutChildren( pFormData );
}
@@ -571,9 +571,9 @@ Image FmControlData::GetImage(const ImageList& ilNavigatorImages) const
}
//------------------------------------------------------------------------
-sal_Bool FmControlData::IsEqualWithoutChilds( FmEntryData* pEntryData )
+sal_Bool FmControlData::IsEqualWithoutChildren( FmEntryData* pEntryData )
{
- RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmControlData::IsEqualWithoutChilds" );
+ RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "FmControlData::IsEqualWithoutChildren" );
if(this == pEntryData)
return sal_True;
@@ -584,7 +584,7 @@ sal_Bool FmControlData::IsEqualWithoutChilds( FmEntryData* pEntryData )
if( (XFormComponent*)m_xFormComponent.get() != (XFormComponent*)pControlData->GetFormComponent().get() )
return sal_False;
- return FmEntryData::IsEqualWithoutChilds( pControlData );
+ return FmEntryData::IsEqualWithoutChildren( pControlData );
}
//------------------------------------------------------------------------
diff --git a/svx/source/form/fmshimp.cxx b/svx/source/form/fmshimp.cxx
index 6aea3ed8f127..e261c21b51fc 100644
--- a/svx/source/form/fmshimp.cxx
+++ b/svx/source/form/fmshimp.cxx
@@ -2703,7 +2703,7 @@ void FmXFormShell::impl_RemoveElement_nothrow(const Reference< XInterface>& Elem
if (xSelSupplier.is())
xSelSupplier->removeSelectionChangeListener(this);
- // remove connection to childs
+ // remove connection to children
const Reference< XIndexContainer> xContainer(Element, UNO_QUERY);
if (xContainer.is())
{
diff --git a/svx/source/form/fmvwimp.cxx b/svx/source/form/fmvwimp.cxx
index ac668ebb5da5..a137968a3ed0 100644
--- a/svx/source/form/fmvwimp.cxx
+++ b/svx/source/form/fmvwimp.cxx
@@ -299,7 +299,7 @@ void SAL_CALL FormViewPageWindowAdapter::makeVisible( const Reference< XControl
}
//------------------------------------------------------------------------
-Reference< XFormController > getControllerSearchChilds( const Reference< XIndexAccess > & xIndex, const Reference< XTabControllerModel > & xModel)
+Reference< XFormController > getControllerSearchChildren( const Reference< XIndexAccess > & xIndex, const Reference< XTabControllerModel > & xModel)
{
if (xIndex.is() && xIndex->getCount())
{
@@ -312,7 +312,7 @@ Reference< XFormController > getControllerSearchChilds( const Reference< XIndex
return xController;
else
{
- xController = getControllerSearchChilds(Reference< XIndexAccess > (xController, UNO_QUERY), xModel);
+ xController = getControllerSearchChildren(Reference< XIndexAccess > (xController, UNO_QUERY), xModel);
if ( xController.is() )
return xController;
}
@@ -333,7 +333,7 @@ Reference< XFormController > FormViewPageWindowAdapter::getController( const Re
return *i;
// the current-round controller isn't the right one. perhaps one of it's children ?
- Reference< XFormController > xChildSearch = getControllerSearchChilds(Reference< XIndexAccess > (*i, UNO_QUERY), xModel);
+ Reference< XFormController > xChildSearch = getControllerSearchChildren(Reference< XIndexAccess > (*i, UNO_QUERY), xModel);
if (xChildSearch.is())
return xChildSearch;
}
diff --git a/svx/source/form/formcontroller.cxx b/svx/source/form/formcontroller.cxx
index 8934926cbc87..7c854bf9f20b 100644
--- a/svx/source/form/formcontroller.cxx
+++ b/svx/source/form/formcontroller.cxx
@@ -1126,7 +1126,7 @@ void SAL_CALL FormController::setActiveTerm( ::sal_Int32 _ActiveTerm ) throw (In
sal_Bool SAL_CALL FormController::hasElements(void) throw( RuntimeException )
{
::osl::MutexGuard aGuard( m_aMutex );
- return !m_aChilds.empty();
+ return !m_aChildren.empty();
}
//------------------------------------------------------------------------------
@@ -1149,7 +1149,7 @@ Reference< XEnumeration > SAL_CALL FormController::createEnumeration(void) thro
sal_Int32 SAL_CALL FormController::getCount(void) throw( RuntimeException )
{
::osl::MutexGuard aGuard( m_aMutex );
- return m_aChilds.size();
+ return m_aChildren.size();
}
//------------------------------------------------------------------------------
@@ -1157,10 +1157,10 @@ Any SAL_CALL FormController::getByIndex(sal_Int32 Index) throw( IndexOutOfBounds
{
::osl::MutexGuard aGuard( m_aMutex );
if (Index < 0 ||
- Index >= (sal_Int32)m_aChilds.size())
+ Index >= (sal_Int32)m_aChildren.size())
throw IndexOutOfBoundsException();
- return makeAny( m_aChilds[ Index ] );
+ return makeAny( m_aChildren[ Index ] );
}
// EventListener
@@ -1237,8 +1237,8 @@ void FormController::disposing(void)
implSetCurrentControl( NULL );
// clean up our children
- for (FmFormControllers::const_iterator i = m_aChilds.begin();
- i != m_aChilds.end(); ++i)
+ for (FmFormControllers::const_iterator i = m_aChildren.begin();
+ i != m_aChildren.end(); ++i)
{
// search the position of the model within the form
Reference< XFormComponent > xForm((*i)->getModel(), UNO_QUERY);
@@ -1258,7 +1258,7 @@ void FormController::disposing(void)
Reference< XComponent > (*i, UNO_QUERY)->dispose();
}
- m_aChilds.clear();
+ m_aChildren.clear();
disposeAllFeaturesAndDispatchers();
@@ -3059,7 +3059,7 @@ void SAL_CALL FormController::addChildController( const Reference< XFormControll
throw IllegalArgumentException( ::rtl::OUString(), *this, 1 );
// TODO: (localized) error message
- m_aChilds.push_back( _ChildController );
+ m_aChildren.push_back( _ChildController );
_ChildController->setParent( *this );
// search the position of the model within the form
@@ -3529,8 +3529,8 @@ void FormController::setMode(const ::rtl::OUString& Mode) throw( NoSupportExcept
else
stopFiltering();
- for (FmFormControllers::const_iterator i = m_aChilds.begin();
- i != m_aChilds.end(); ++i)
+ for (FmFormControllers::const_iterator i = m_aChildren.begin();
+ i != m_aChildren.end(); ++i)
{
Reference< XModeSelector > xMode(*i, UNO_QUERY);
if ( xMode.is() )
diff --git a/svx/source/form/navigatortreemodel.cxx b/svx/source/form/navigatortreemodel.cxx
index 0e89ce1f37c1..e5f3c8501b08 100644
--- a/svx/source/form/navigatortreemodel.cxx
+++ b/svx/source/form/navigatortreemodel.cxx
@@ -822,10 +822,10 @@ namespace svxform
RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "svx", "Ocke.Janssen@sun.com", "NavigatorTreeModel::InsertFormComponent" );
if ( pObject->ISA(SdrObjGroup) )
{ // rekursiv absteigen
- const SdrObjList *pChilds = ((SdrObjGroup*)pObject)->GetSubList();
- for ( sal_uInt16 i=0; i<pChilds->GetObjCount(); ++i )
+ const SdrObjList *pChildren = ((SdrObjGroup*)pObject)->GetSubList();
+ for ( sal_uInt16 i=0; i<pChildren->GetObjCount(); ++i )
{
- SdrObject* pCurrent = pChilds->GetObj(i);
+ SdrObject* pCurrent = pChildren->GetObj(i);
if (!InsertFormComponent(rHint, pCurrent))
return sal_False;
}
diff --git a/svx/source/inc/fmexpl.hxx b/svx/source/inc/fmexpl.hxx
index 7070eac032e4..4e733d52f307 100644
--- a/svx/source/inc/fmexpl.hxx
+++ b/svx/source/inc/fmexpl.hxx
@@ -183,7 +183,7 @@ public:
FmEntryData* GetParent() const { return pParent; }
FmEntryDataList* GetChildList() const { return pChildList; }
- virtual sal_Bool IsEqualWithoutChilds( FmEntryData* pEntryData );
+ virtual sal_Bool IsEqualWithoutChildren( FmEntryData* pEntryData );
virtual FmEntryData* Clone() = 0;
// note that the interface returned is normalized, i.e. querying the given XInterface of the object
@@ -275,7 +275,7 @@ public:
const ::com::sun::star::uno::Reference< ::com::sun::star::form::XForm >& GetFormIface() const { return m_xForm; }
const ::com::sun::star::uno::Reference< ::com::sun::star::container::XContainer >& GetContainer() const { return m_xContainer; }
- virtual sal_Bool IsEqualWithoutChilds( FmEntryData* pEntryData );
+ virtual sal_Bool IsEqualWithoutChildren( FmEntryData* pEntryData );
virtual FmEntryData* Clone();
};
@@ -299,7 +299,7 @@ public:
virtual ~FmControlData();
const ::com::sun::star::uno::Reference< ::com::sun::star::form::XFormComponent >& GetFormComponent() const { return m_xFormComponent; }
- virtual sal_Bool IsEqualWithoutChilds( FmEntryData* pEntryData );
+ virtual sal_Bool IsEqualWithoutChildren( FmEntryData* pEntryData );
virtual FmEntryData* Clone();
void ModelReplaced(
diff --git a/svx/source/inc/formcontroller.hxx b/svx/source/inc/formcontroller.hxx
index f362d59802fe..5e6530f26fca 100644
--- a/svx/source/inc/formcontroller.hxx
+++ b/svx/source/inc/formcontroller.hxx
@@ -175,7 +175,7 @@ namespace svxform
m_aParameterListeners,
m_aFilterListeners;
- FmFormControllers m_aChilds;
+ FmFormControllers m_aChildren;
FilterComponents m_aFilterComponents;
FmFilterRows m_aFilterRows;
diff --git a/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx b/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx
index 613ff0b76514..6100860d3926 100644
--- a/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx
+++ b/svx/source/unodialogs/textconversiondlgs/chinese_dictionarydialog.cxx
@@ -271,7 +271,7 @@ void DictionaryList::deleteEntryOnPos( sal_Int32 nPos )
SvLBoxEntry* pLBEntry = GetEntryOnPos( nPos );
DictionaryEntry* pEntry = getEntryOnPos( nPos );
if( pLBEntry )
- RemoveParentKeepChilds( pLBEntry );
+ RemoveParentKeepChildren( pLBEntry );
if( pEntry )
{
if( pEntry->m_bNewEntry )
@@ -291,7 +291,7 @@ sal_uIntPtr DictionaryList::deleteEntries( const rtl::OUString& rTerm )
{
nPos = nN;
SvLBoxEntry* pCurLBEntry = GetEntryOnPos( nN );
- RemoveParentKeepChilds( pCurLBEntry );
+ RemoveParentKeepChildren( pCurLBEntry );
if( pCurEntry->m_bNewEntry )
delete pCurEntry;
else
diff --git a/svx/source/accessibility/svxrectctaccessiblecontext.cxx b/svx/source/accessibility/svxrectctaccessiblecontext.cxx
index 873c00f42576..fa57706dc255 100644
--- a/svx/source/accessibility/svxrectctaccessiblecontext.cxx
+++ b/svx/source/accessibility/svxrectctaccessiblecontext.cxx
@@ -57,7 +57,7 @@ using namespace ::com::sun::star::uno;
using namespace ::com::sun::star::accessibility;
-#define MAX_NUM_OF_CHILDS 9
+#define MAX_NUM_OF_CHILDREN 9
#define NOCHILDSELECTED -1
@@ -153,10 +153,10 @@ SvxRectCtlAccessibleContext::SvxRectCtlAccessibleContext(
SvxRectCtlAccessibleContext_Base( m_aMutex ),
mxParent( rxParent ),
mpRepr( &rRepr ),
- mpChilds( NULL ),
+ mpChildren( NULL ),
mnClientId( 0 ),
mnSelectedChild( NOCHILDSELECTED ),
- mbAngleMode( rRepr.GetNumOfChilds() == 8 )
+ mbAngleMode( rRepr.GetNumOfChildren() == 8 )
{
DBG_CTOR( SvxRectCtlAccessibleContext, NULL );
@@ -176,10 +176,10 @@ SvxRectCtlAccessibleContext::SvxRectCtlAccessibleContext(
msDescription = SVX_RESSTR( mbAngleMode? RID_SVXSTR_RECTCTL_ACC_ANGL_DESCR : RID_SVXSTR_RECTCTL_ACC_CORN_DESCR );
}
- mpChilds = new SvxRectCtlChildAccessibleContext*[ MAX_NUM_OF_CHILDS ];
+ mpChildren = new SvxRectCtlChildAccessibleContext*[ MAX_NUM_OF_CHILDREN ];
- SvxRectCtlChildAccessibleContext** p = mpChilds;
- for( int i = MAX_NUM_OF_CHILDS ; i ; --i, ++p )
+ SvxRectCtlChildAccessibleContext** p = mpChildren;
+ for( int i = MAX_NUM_OF_CHILDREN ; i ; --i, ++p )
*p = NULL;
}
@@ -191,7 +191,7 @@ SvxRectCtlAccessibleContext::~SvxRectCtlAccessibleContext()
if( IsAlive() )
{
osl_incrementInterlockedCount( &m_refCount );
- dispose(); // set mpRepr = NULL & release all childs
+ dispose(); // set mpRepr = NULL & release all children
}
}
@@ -278,7 +278,7 @@ sal_Int32 SAL_CALL SvxRectCtlAccessibleContext::getAccessibleChildCount( void )
ThrowExceptionIfNotAlive();
- return mpRepr->GetNumOfChilds();
+ return mpRepr->GetNumOfChildren();
}
Reference< XAccessible > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleChild( sal_Int32 nIndex )
@@ -286,7 +286,7 @@ Reference< XAccessible > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleChil
{
checkChildIndex( nIndex );
- Reference< XAccessible > xChild = mpChilds[ nIndex ];
+ Reference< XAccessible > xChild = mpChildren[ nIndex ];
if( !xChild.is() )
{
::SolarMutexGuard aSolarGuard;
@@ -295,7 +295,7 @@ Reference< XAccessible > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleChil
ThrowExceptionIfNotAlive();
- xChild = mpChilds[ nIndex ];
+ xChild = mpChildren[ nIndex ];
if( !xChild.is() )
{
@@ -311,7 +311,7 @@ Reference< XAccessible > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleChil
SvxRectCtlChildAccessibleContext* pChild = new SvxRectCtlChildAccessibleContext(
this, *mpRepr, aName, aDescr, aFocusRect, nIndex );
- xChild = mpChilds[ nIndex ] = pChild;
+ xChild = mpChildren[ nIndex ] = pChild;
pChild->acquire();
// set actual state
@@ -640,13 +640,13 @@ void SvxRectCtlAccessibleContext::selectChild( long nNew )
::osl::MutexGuard aGuard( m_aMutex );
if( nNew != mnSelectedChild )
{
- long nNumOfChilds = getAccessibleChildCount();
- if( nNew < nNumOfChilds )
+ long nNumOfChildren = getAccessibleChildCount();
+ if( nNew < nNumOfChildren )
{ // valid index
SvxRectCtlChildAccessibleContext* pChild;
if( mnSelectedChild != NOCHILDSELECTED )
{ // deselect old selected child if one is selected
- pChild = mpChilds[ mnSelectedChild ];
+ pChild = mpChildren[ mnSelectedChild ];
if( pChild )
pChild->setStateChecked( sal_False );
}
@@ -656,7 +656,7 @@ void SvxRectCtlAccessibleContext::selectChild( long nNew )
if( nNew != NOCHILDSELECTED )
{
- pChild = mpChilds[ nNew ];
+ pChild = mpChildren[ nNew ];
if( pChild )
pChild->setStateChecked( sal_True );
}
@@ -718,8 +718,8 @@ void SAL_CALL SvxRectCtlAccessibleContext::disposing()
::osl::MutexGuard aGuard( m_aMutex );
mpRepr = NULL; // object dies with representation
- SvxRectCtlChildAccessibleContext** p = mpChilds;
- for( int i = MAX_NUM_OF_CHILDS ; i ; --i, ++p )
+ SvxRectCtlChildAccessibleContext** p = mpChildren;
+ for( int i = MAX_NUM_OF_CHILDREN ; i ; --i, ++p )
{
SvxRectCtlChildAccessibleContext* pChild = *p;
if( pChild )
@@ -730,8 +730,8 @@ void SAL_CALL SvxRectCtlAccessibleContext::disposing()
}
}
- delete[] mpChilds;
- mpChilds = NULL;
+ delete[] mpChildren;
+ mpChildren = NULL;
}
{
@@ -825,7 +825,7 @@ SvxRectCtlChildAccessibleContext::~SvxRectCtlChildAccessibleContext()
if( IsAlive() )
{
osl_incrementInterlockedCount( &m_refCount );
- dispose(); // set mpRepr = NULL & release all childs
+ dispose(); // set mpRepr = NULL & release all children
}
}
diff --git a/svx/source/form/navigatortree.cxx b/svx/source/form/navigatortree.cxx
index 4b67905fc43b..df1c845e9c84 100644
--- a/svx/source/form/navigatortree.cxx
+++ b/svx/source/form/navigatortree.cxx
@@ -563,7 +563,7 @@ namespace svxform
while( pCurEntry )
{
pCurEntryData = (FmEntryData*)pCurEntry->GetUserData();
- if( pCurEntryData && pCurEntryData->IsEqualWithoutChilds(pEntryData) )
+ if( pCurEntryData && pCurEntryData->IsEqualWithoutChildren(pEntryData) )
return pCurEntry;
pCurEntry = Next( pCurEntry );
@@ -658,7 +658,7 @@ namespace svxform
Expand( m_pRootEntry );
//////////////////////////////////////////////////////////////////////
- // Childs einfuegen
+ // Children einfuegen
FmEntryDataList* pChildList = pEntryData->GetChildList();
size_t nChildCount = pChildList->size();
FmEntryData* pChildData;
@@ -914,7 +914,7 @@ namespace svxform
m_aDropActionType = DA_SCROLLDOWN;
bNeedTrigger = sal_True;
} else
- { // auf einem Entry mit Childs, der nicht aufgeklappt ist ?
+ { // auf einem Entry mit Children, der nicht aufgeklappt ist ?
SvLBoxEntry* pDropppedOn = GetEntry(aDropPos);
if (pDropppedOn && (GetChildCount(pDropppedOn) > 0) && !IsExpanded(pDropppedOn))
{
@@ -1964,7 +1964,7 @@ namespace svxform
// und selektiere diesen (waere irgendwie intuitiver ;)) 2) ich gehe durch alle meine SvLBoxEntries und selektiere
// genau die, die ich in der SelectList finde
// 1) braucht O(k*n) (k=Laenge der SelectList, n=Anzahl meiner Entries), plus den Fakt, dass FindEntry nicht den
// Pointer auf die UserDaten vergleicht, sondern ein aufwendigeres IsEqualWithoutChilds durchfuehrt
// 2) braucht O(n*log k), dupliziert aber etwas Code (naemlich den aus FindEntry)
// da das hier eine relativ oft aufgerufenen Stelle sein koennte (bei jeder Aenderung in der Markierung in der View !),
// nehme ich doch lieber letzteres
@@ -1964,7 +1964,7 @@ namespace svxform
// genau die, die ich in der SelectList finde
// 1) braucht O(k*n) (k=Laenge der SelectList, n=Anzahl meiner Entries), plus den Fakt, dass FindEntry nicht den
- // Pointer auf die UserDaten vergleicht, sondern ein aufwendigeres IsEqualWithoutChilds durchfuehrt
+ // Pointer auf die UserDaten vergleicht, sondern ein aufwendigeres IsEqualWithoutChildren durchfuehrt
// 2) braucht O(n*log k), dupliziert aber etwas Code (naemlich den aus FindEntry)
// da das hier eine relativ oft aufgerufenen Stelle sein koennte (bei jeder Aenderung in der Markierung in der View !),
diff --git a/svx/source/inc/svxrectctaccessiblecontext.hxx b/svx/source/inc/svxrectctaccessiblecontext.hxx
index ae5982f16644..d5dd9204db4a 100644
--- a/svx/source/inc/svxrectctaccessiblecontext.hxx
+++ b/svx/source/inc/svxrectctaccessiblecontext.hxx
@@ -311,8 +311,8 @@ private:
/// pointer to internal representation
SvxRectCtl* mpRepr;
- /// array for all possible childs
- SvxRectCtlChildAccessibleContext** mpChilds;
+ /// array for all possible children
+ SvxRectCtlChildAccessibleContext** mpChildren;
/// client id in the AccessibleEventNotifier queue
sal_uInt32 mnClientId;